==> 1.3.0.tar.gz: ios/Classes/Models/NativeToFlutter/FireworkSDK+ConvertToJson.swift <==
//
//  Firework+JsEvent.swift
//  react-native-firework-sdk
//
//  Created by Jeff on 2021/12/21.
//

import Foundation
import FireworkVideo

extension FireworkVideoSDKError {
    var jsErrorName: String {
        switch self {
        case .missingAppID:
            return "missingAppID"
        case .missingPublisherID:
            return "missingPublisherID"
        case .authenticationFailure:
            return "authenticationFailure"
        default:
            return "unknow"
        }
    }
}

extension VideoPlaybackDetails {
    var jsObject: [String: Any?] {
        [ "videoId": videoID,
         "duration": duration,
         "caption": caption,
         "badge": badge,
         "playerSize": ["width": playerSize.width,
                         "height": playerSize.height],
         "hasCTA": hasCTA]
    }
}

extension VideoFeedError {
    var jsObject: [String: String] {
        var error: [String: String] = [:]
        switch self {
        case .contentSourceError(let sourceError):
            error = ["name": "contentSourceError", "reason": sourceError.failureReason ?? "Content source error"]
        case .videoShareError(let shareError):
            error = ["name": "videoShareError", "reason": shareError.failureReason ?? "Video share error"]
        case .unknownError(let unknownError):
            error = ["name": "unknownError", "reason": unknownError.localizedDescription]
        default:
            error = ["name": "unknownError", "reason": "Unknown error"]
        }
        
        return error
    }
}

extension FeedEventDetails {
    var jsObject: [String: Any] {
        var result: [String: Any] = [
            "index": index,
            "id": id,
            "duration": duration,
        ]
        if let title = caption {
            result["title"] = title
        }

        var sourceStr: String = ""
        switch(source) {
        case .discover:
            sourceStr = "discover"
        case .channel(channelID: let channelID):
            sourceStr = "channel"
            result["channel"] = channelID
        case .channelPlaylist(channelID: let channelID, playlistID: let playlistID):
            sourceStr = "playlist"
            result["channel"] = channelID
            result["playlist"] = playlistID
        case .playlistGroup(groupID: let playlistGroupID):
            sourceStr = "playlistGroup"
            result["playlistGroup"] = playlistGroupID
        case .dynamicContent(channelID: let channelID, parameters: let parameters):
            sourceStr = "dynamicContent"
            result["channel"] = channelID
            result["dynamicContentParameters"] = parameters
        default:
            break
        }

        result["source"] = sourceStr;

        return result
    }
}

extension LiveStreamEventDetails {
    var jsObject: [String: Any] {
        return ["id": id]
    }
}

extension LiveStreamMessageDetails {
    var jsObject: [String: Any] {
        return [
            "messageId": messageID,
            "username": username,
            "text": text
        ]
    }
}

extension StoryBlockError {
    var jsObject: [String: String] {
        var error: [String: String] = [:]
        switch self {
        case .contentSourceError(let sourceError):
            error = ["name": "contentSourceError", "reason": sourceError.failureReason ?? "Content source error"]
        case .videoShareError(let shareError):
            error = ["name": "videoShareError", "reason": shareError.failureReason ?? "Video share error"]
        case .unknownError(underlyingError: let unknownError):
            error = ["name": "unknownError", "reason": unknownError.localizedDescription]
        default:
            error = ["name": "unknownError", "reason": "Unknown error"]
        }

        return error
    }
}

==> 1.5.1.tar.gz: ios/Classes/Models/NativeToFlutter/FireworkSDK+ConvertToJson.swift <==
//
//  Firework+JsEvent.swift
//  react-native-firework-sdk
//
//  Created by Jeff on 2021/12/21.
//

import FireworkVideo
import Foundation

extension FireworkVideoSDKError {
    var jsErrorName: String {
        switch self {
        case .missingAppID:
            return "missingAppID"
        case .missingPublisherID:
            return "missingPublisherID"
        case .authenticationFailure:
            return "authenticationFailure"
        default:
            return "unknow"
        }
    }
}

extension VideoPlaybackDetails {
    var jsObject: [String: Any?] {
        [
            "videoId": videoID,
            "duration": duration,
            "caption": caption,
            "badge": badge,
            "playerSize": [
                "width": playerSize.width,
                "height": playerSize.height
            ],
            "hasCTA": hasCTA
        ]
    }
}

extension VideoFeedError {
    var jsObject: [String: String] {
        var error: [String: String] = [:]
        switch self {
        case .contentSourceError(let sourceError):
            error = [
                "name": "contentSourceError",
                "reason": sourceError.failureReason ?? "Content source error"
            ]
        case .videoShareError(let shareError):
            error = [
                "name": "videoShareError",
                "reason": shareError.failureReason ?? "Video share error"
            ]
        case .unknownError(let unknownError):
            error = ["name": "unknownError", "reason": unknownError.localizedDescription]
        default:
            error = ["name": "unknownError", "reason": "Unknown error"]
        }

        return error
    }
}

extension FeedEventDetails {
    var jsObject: [String: Any] {
        var result: [String: Any] = [
            "index": index,
            "id": id,
            "duration": duration
        ]
        if let title = caption {
            result["title"] = title
        }

        var sourceStr: String = ""
        switch source {
        case .discover:
            sourceStr = "discover"
        case .channel(let channelID):
            sourceStr = "channel"
            result["channel"] = channelID
        case .channelPlaylist(let channelID, let playlistID):
            sourceStr = "playlist"
            result["channel"] = channelID
            result["playlist"] = playlistID
        case .playlistGroup(groupID: let playlistGroupID):
            sourceStr = "playlistGroup"
            result["playlistGroup"] = playlistGroupID
        case .dynamicContent(let channelID, let parameters):
            sourceStr = "dynamicContent"
            result["channel"] = channelID
            result["dynamicContentParameters"] = parameters
        default:
            break
        }

        result["source"] = sourceStr

        return result
    }
}

extension LiveStreamEventDetails {
    var jsObject: [String: Any] {
        return ["id": id]
    }
}

extension LiveStreamMessageDetails {
    var jsObject: [String: Any] {
        return [
            "messageId": messageID,
            "username": username,
            "text": text
        ]
    }
}

extension StoryBlockError {
    var jsObject: [String: String] {
        var error: [String: String] = [:]
        switch self {
        case .contentSourceError(let sourceError):
            error = [
                "name": "contentSourceError",
                "reason": sourceError.failureReason ?? "Content source error"
            ]
        case .videoShareError(let shareError):
            error = [
                "name": "videoShareError",
                "reason": shareError.failureReason ?? "Video share error"
            ]
        case .unknownError(underlyingError: let unknownError):
            error = ["name": "unknownError", "reason": unknownError.localizedDescription]
        default:
            error = ["name": "unknownError", "reason": "Unknown error"]
        }

        return error
    }
}
